==> dffml-model-tensorflow-0.1.1.tar.gz: dffml-model-tensorflow-0.1.1/setup.py <==
import os
import ast
from io import open

from setuptools import find_packages, setup

self_path = os.path.dirname(os.path.realpath(__file__))

with open(os.path.join(self_path, 'dffml_model_tensorflow', 'version.py'),
          'r') as f:
    for line in f:
        if line.startswith('VERSION'):
            version = ast.literal_eval(line.strip().split('=')[-1].strip())
            break

with open(os.path.join(self_path, 'README.rst'), 'r', encoding='utf-8') as f:
    readme = f.read()

with open(os.path.join(self_path, 'requirements.txt'), 'r',
          encoding='utf-8') as f:
    INSTALL_REQUIRES = [line for line in f]

setup(
    name='dffml-model-tensorflow',
    version=version,
    description='',
    long_description=readme,
    author='John Andersen',
    author_email='john.s.andersen@intel.com',
    url='https://github.com/intel/dffml/blob/master/model/tensorflow/README.rst',
    license='MIT',

    keywords=[
        '',
    ],

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=INSTALL_REQUIRES,

    packages=find_packages(),
    entry_points={
        'dffml.model': [
            'dnn = dffml_model_tensorflow.model.dnn:DNN',
        ],
    },
)

==> dffml-model-tensorflow-0.1.2.tar.gz: dffml-model-tensorflow-0.1.2/setup.py <==
import os
import ast
from io import open

from setuptools import find_packages, setup

self_path = os.path.dirname(os.path.realpath(__file__))

with open(os.path.join(self_path, 'dffml_model_tensorflow', 'version.py'),
          'r') as f:
    for line in f:
        if line.startswith('VERSION'):
            version = ast.literal_eval(line.strip().split('=')[-1].strip())
            break

with open(os.path.join(self_path, 'README.rst'), 'r', encoding='utf-8') as f:
    readme = f.read()

INSTALL_REQUIRES = [
    "tensorflow>=1.13.1,<2.0.0"
    ]

setup(
    name='dffml-model-tensorflow',
    version=version,
    description='',
    long_description=readme,
    author='John Andersen',
    author_email='john.s.andersen@intel.com',
    url='https://github.com/intel/dffml/blob/master/model/tensorflow/README.rst',
    license='MIT',

    keywords=[
        '',
    ],

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    install_requires=INSTALL_REQUIRES,

    packages=find_packages(),
    entry_points={
        'dffml.model': [
            'dnn = dffml_model_tensorflow.model.dnn:DNN',
        ],
    },
)
